akmeans-package:
Adaptive K-means
Description
This package provides two things.
At first, K-means based on cosine distance is provided as a component of this package. Then, based on existing 'kmeans' function and the new kmeans with cosine distance, adaptive part is implemented using various thresholds.
Details
|
Package: |
| akmeans |
|
Type: |
| Package |
|
Version: |
| 1.1 |
|
Date: |
| 2014-04-08 |
|
License: |
| GPL-2 |
|
LazyLoad: |
| yes |
- akmeans - the main function, adaptive kmeans algorithm
- norm.sim.ksc - kmeans based on cosine distance